@@ -31,15 +31,24 @@ sub new {
     $obj;
 }
 
+use Fcntl;
+use IO::File;
+
 sub run {
     my $obj = shift;
     use IO::File;
     my $pid = (my $fh = new IO::File)->open('-|') // die "open: $@\n";
     if ($pid == 0) {
+	if (my $stdin = $obj->{STDIN}) {
+	    open STDIN, "<&=", $stdin->fileno or die "open: $!\n";
+	    $stdin->fcntl(F_SETFD, 0) or die "fcntl F_SETFD: $!\n";
+	    binmode STDIN, ':encoding(utf8)';
+	}
 	open STDERR, ">&STDOUT";
 	$obj->execute;
 	exit 1;
     }
+    $obj->{STDIN} = undef;
     binmode $fh, ':encoding(utf8)';
     $obj->{stdout} = do { local $/; <$fh> };
     my $child = wait;
@@ -67,4 +76,20 @@ sub execute {
     exec $^X, "-I$lib", $command, @option;
 }
 
+sub setstdin {
+    my $obj = shift;
+    my $data = shift;
+    my $stdin = $obj->{STDIN} //= do {
+	my $fh = new_tmpfile IO::File or die "new_tmpfile: $!\n";
+	$fh->fcntl(F_SETFD, 0) or die "fcntl F_SETFD: $!\n";
+	binmode $fh, ':encoding(utf8)';
+	$fh;
+    };
+    $stdin->seek(0, 0)  or die "seek: $!\n";
+    $stdin->truncate(0) or die "truncate: $!\n";
+    $stdin->print($data);
+    $stdin->seek(0, 0)  or die "seek: $!\n";
+    $obj;
+}
+
 1;
